@@ -257,7 +257,7 @@ class XMI:
 		requirement = addElement(self.doc, 'UML:ClassifierRole', parent)
 		requirement.setProp('isAbstract', 'false')
 		requirement.setProp('isLeaf', 'false')
-		requirement.setProp('isRoot', 'true')
+		requirement.setProp('isRoot', 'false')
 		requirement.setProp('isSpecification', 'false')
 		requirement.setProp('name', name)
 		requirement.setProp('visibility', 'public')
@@ -273,7 +273,7 @@ class XMI:
 		actor = addElement(self.doc, 'UML:Actor', parent)
 		actor.setProp('isAbstract', 'false')
 		actor.setProp('isLeaf', 'false')
-		actor.setProp('isRoot', 'true')
+		actor.setProp('isRoot', 'false')
 		actor.setProp('isSpecification', 'false')
 		actor.setProp('name', name)
 		actor.setProp('visibility', 'public')
@@ -288,7 +288,7 @@ class XMI:
 		useCase = addElement(self.doc, 'UML:UseCase', parent)
 		useCase.setProp('isAbstract', 'false')
 		useCase.setProp('isLeaf', 'false')
-		useCase.setProp('isRoot', 'true')
+		useCase.setProp('isRoot', 'false')
 		useCase.setProp('isSpecification', 'false')
 		useCase.setProp('name', name)
 		useCase.setProp('visibility', 'public')
@@ -303,7 +303,7 @@ class XMI:
 		system = addElement(self.doc, 'UML:Component', parent)
 		system.setProp('isAbstract', 'false')
 		system.setProp('isLeaf', 'false')
-		system.setProp('isRoot', 'true')
+		system.setProp('isRoot', 'false')
 		system.setProp('isSpecification', 'false')
 		system.setProp('name', name)
 		system.setProp('visibility', 'public')
@@ -319,7 +319,7 @@ class XMI:
 		clasz = addElement(self.doc, 'UML:Class', parent)
 		clasz.setProp('isAbstract', 'false')
 		clasz.setProp('isLeaf', 'false')
-		clasz.setProp('isRoot', 'true')
+		clasz.setProp('isRoot', 'false')
 		clasz.setProp('isSpecification', 'false')
 		clasz.setProp('name', name)
 		clasz.setProp('visibility', 'public')
